@@ -170,7 +170,7 @@ class Model(BaseModel[Property]):
         if not self.check_schema(self.schema):
             raise ValueError(f"schema {name!r} is invalid.")
 
-        self.validator = self.VALIDATOR(self.schema)
+        self.validator = self.VALIDATOR(self.schema, types={"array": (list, tuple)})
 
         if (
             "type" not in self.schema
@@ -231,8 +231,7 @@ class Model(BaseModel[Property]):
         for key, value in instance.items():
             if key in self:
                 self[key].value = value
-
-        self.notify(self)
+                self.notify(self, self[key])
 
         return True, None
 
